==> kubernetes-model-admissionregistration-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/SelfSubjectAccessReviewSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SelfSubjectAccessReviewSpecBuilder extends io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpec,io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecBuilder>{
  public SelfSubjectAccessReviewSpecBuilder() {
    this(false);
  }
  public SelfSubjectAccessReviewSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new SelfSubjectAccessReviewSpec(), validationEnabled);
  }
  public SelfSubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SelfSubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SelfSubjectAccessReviewSpec(), validationEnabled);
  }
  public SelfSubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpec instance) {
    this(fluent, instance, false);
  }
  public SelfSubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withNonResourceAttributes(instance.getNonResourceAttributes()); 
    fluent.withResourceAttributes(instance.getResourceAttributes()); 
    this.validationEnabled = validationEnabled; 
  }
  public SelfSubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpec instance) {
    this(instance,false);
  }
  public SelfSubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withNonResourceAttributes(instance.getNonResourceAttributes()); 
    this.withResourceAttributes(instance.getResourceAttributes()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpec build() {
    SelfSubjectAccessReviewSpec buildable = new SelfSubjectAccessReviewSpec(fluent.getNonResourceAttributes(),fluent.getResourceAttributes());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SelfSubjectAccessReviewSpecBuilder that = (SelfSubjectAccessReviewSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-admissionregistration-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/SelfSubjectAccessReviewSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SelfSubjectAccessReviewSpecBuilder extends io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpec,io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecBuilder>{
  public SelfSubjectAccessReviewSpecBuilder() {
    this(false);
  }
  public SelfSubjectAccessReviewSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new SelfSubjectAccessReviewSpec(), validationEnabled);
  }
  public SelfSubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SelfSubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SelfSubjectAccessReviewSpec(), validationEnabled);
  }
  public SelfSubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpec instance) {
    this(fluent, instance, false);
  }
  public SelfSubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withNonResourceAttributes(instance.getNonResourceAttributes()); 
    fluent.withResourceAttributes(instance.getResourceAttributes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SelfSubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpec instance) {
    this(instance,false);
  }
  public SelfSubjectAccessReviewSpecBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withNonResourceAttributes(instance.getNonResourceAttributes()); 
    this.withResourceAttributes(instance.getResourceAttributes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.authorization.v1beta1.SelfSubjectAccessReviewSpec build() {
    SelfSubjectAccessReviewSpec buildable = new SelfSubjectAccessReviewSpec(fluent.getNonResourceAttributes(),fluent.getResourceAttributes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SelfSubjectAccessReviewSpecBuilder that = (SelfSubjectAccessReviewSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
